@@ -455,6 +455,9 @@ ldap_disco (const char *domain,
 	const char *addrs[DISCO_COUNT];
 	int found = ADCLI_DISCO_UNUSABLE;
 	LDAPMessage *message;
+	char buffer[1024];
+	struct addrinfo hints;
+	struct addrinfo *res, *ai;
 	const char *scheme;
 	int msgidp;
 	int version;
@@ -487,25 +490,61 @@ ldap_disco (const char *domain,
 	else
 		scheme = "ldap";
 
-	for (num = 0; num < DISCO_COUNT && srv != NULL; srv = srv->next) {
-		if (asprintf (&url, "%s://%s", scheme, srv->hostname) < 0)
-			return_val_if_reached (0);
+	/*
+	 * The ai_socktype and ai_protocol hint fields are unused below,
+	 * but are set in order to prevent duplicate returns from
+	 * getaddrinfo().
+	 */
+	memset (&hints, 0, sizeof (hints));
+	hints.ai_socktype = SOCK_STREAM;
+	hints.ai_protocol = IPPROTO_TCP;
+	hints.ai_flags |= AI_NUMERICSERV;
+#ifdef AI_ADDRCONFIG
+	hints.ai_flags |= AI_ADDRCONFIG;
+#endif
 
-		ret = ldap_initialize (&ldap[num], url);
-		if (ret == LDAP_SUCCESS) {
-			version = LDAP_VERSION3;
-			ldap_set_option (ldap[num], LDAP_OPT_PROTOCOL_VERSION, &version);
-			ldap_set_option (ldap[num], LDAP_OPT_REFERRALS , 0);
-			_adcli_info ("Sending %s pings to domain controller: %s", DISCO_SCHEME, srv->hostname);
-			addrs[num] = srv->hostname;
-			have_any = 1;
-			num++;
-
-		} else {
-			_adcli_err ("Couldn't perform discovery on server: %s: %s", url, ldap_err2string (ret));
+	for (num = 0; srv != NULL; srv = srv->next) {
+		ret = getaddrinfo (srv->hostname, "389", &hints, &res);
+		if (ret != 0) {
+			_adcli_warn ("Couldn't resolve server host: %s: %s",
+			             srv->hostname, gai_strerror (ret));
+			continue;
 		}
 
-		free (url);
+		for (ai = res; num < DISCO_COUNT && ai != NULL; ai  = ai->ai_next) {
+			if (getnameinfo (ai->ai_addr, ai->ai_addrlen, buffer, sizeof (buffer),
+			                 NULL, 0, NI_NUMERICHOST) != 0)
+				return_val_if_reached (0);
+			if (ai->ai_family == AF_INET6) {
+				/*
+				 * Currently openldap has cldap bugs when used with IPv6:
+				 * http://www.openldap.org/its/index.cgi/Incoming?id=7694
+				 */
+				if (asprintf (&url, "%s://[%s]", "ldap", buffer) < 0)
+					return_val_if_reached (0);
+			} else {
+				if (asprintf (&url, "%s://%s", scheme, buffer) < 0)
+					return_val_if_reached (0);
+			}
+
+			ret = ldap_initialize (&ldap[num], url);
+			if (ret == LDAP_SUCCESS) {
+				version = LDAP_VERSION3;
+				ldap_set_option (ldap[num], LDAP_OPT_PROTOCOL_VERSION, &version);
+				ldap_set_option (ldap[num], LDAP_OPT_REFERRALS , 0);
+				_adcli_info ("Sending netlogon pings to domain controller: %s", url);
+				addrs[num] = srv->hostname;
+				have_any = 1;
+				num++;
+
+			} else {
+				_adcli_err ("Couldn't perform discovery on server: %s: %s", url, ldap_err2string (ret));
+			}
+
+			free (url);
+		}
+
+		freeaddrinfo (res);
 	}
 
 	/* Wait for the first response. Poor mans fd watch */
@@ -550,7 +589,7 @@ ldap_disco (const char *domain,
 				ret = ldap_search_ext (ldap[i], "", LDAP_SCOPE_BASE,
 				                       filter, attrs, 0, NULL, NULL, NULL,
 				                       -1, &msgidp);
-				close_ldap = 0;
+				close_ldap = (ret != 0);
 				break;
 			case -1:
 				ldap_get_option (ldap[i], LDAP_OPT_RESULT_CODE, &ret);
